"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const node_css_require_1 = require("node-css-require");
const sha256_1 = __importDefault(require("sha256"));
async function generateCSSInject(sourcePath, css) {
    const styleId = (0, sha256_1.default)(sourcePath);
    return `(function(){
        if (!document.getElementById('${styleId}')) {
            var e = document.createElement('style');
            e.id = '${styleId}';
            e.textContent = \`${css}\`;
            document.head.appendChild(e);
        }
    })();`;
}
const cssPlugin = {
    name: 'css-plugin',
    setup: (build) => {
        build.onLoad({
            filter: /\.css$/,
        }, async (args) => {
            const text = await fs_1.default.promises.readFile(args.path, 'utf8');
            const res = (0, node_css_require_1.compileCss)(text, args.path);
            const js = `${await generateCSSInject(args.path, res.css)}\n${res.js}`;
            return {
                contents: js,
                loader: 'js',
            };
        });
    },
};
const pluginFactory = () => cssPlugin;
exports.default = pluginFactory;
//# sourceMappingURL=esbuildCssModulesClientPlugin.js.map