"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.compress = void 0;
const zlib_1 = __importDefault(require("zlib"));
const compress = (event, result) => {
    // when there is no body, there is nothing to compress
    if (!result.body) {
        return result;
    }
    const acceptEncodingHeader = event.headers['accept-encoding'];
    // determine accepted encodings
    const encodings = new Set();
    if (acceptEncodingHeader) {
        acceptEncodingHeader.split(',').forEach((encoding) => {
            encodings.add(encoding.toLowerCase().trim());
        });
    }
    if (!result.headers) {
        result.headers = {};
    }
    if (encodings.has('br')) {
        result.headers['content-encoding'] = 'br';
        result.isBase64Encoded = true;
        result.body = zlib_1.default.brotliCompressSync(result.body).toString('base64');
        return result;
    }
    if (encodings.has('gzip')) {
        result.headers['content-encoding'] = 'gzip';
        result.isBase64Encoded = true;
        result.body = zlib_1.default.gzipSync(result.body).toString('base64');
        return result;
    }
    if (encodings.has('deflate')) {
        result.headers['content-encoding'] = 'deflate ';
        result.isBase64Encoded = true;
        result.body = zlib_1.default.deflateSync(result.body).toString('base64');
        return result;
    }
    // if there are no supported encodings, return unencoded message
    return result;
};
exports.compress = compress;
//# sourceMappingURL=lambdaCompression.js.map